"use client";
import FormButtons from "@/components/simulation/common/form-buttons";
import Sidebar from "@/components/simulation/common/sidebar";
import { ImageBaseUrl } from "@/configs/api";
import { submitPoolRequest } from "@/servers/actions/pool-request-action";
import { fetchProductById } from "@/servers/actions/product-action";
import { useProduct } from "@/servers/data/use-product";
import { useTranslations } from "next-intl";
import dynamic from "next/dynamic";
import { useRouter, useSearchParams } from "next/navigation";
import React, { useState, useTransition } from "react";
import { toast } from "sonner";
const Scene = dynamic(() => import("@/components/swimming-pool/scene"));


const DefaultSelect = { pool: 1, showWater: true, floor: 1, ladder: 0, waterfall: 0, jacuzzi: 0, lamp: 0, selectedTile: null, selectedLadder: null, selectedLight: null, selectedWaterfall: null };

export default function PoolWaterfalls() {
	const t = useTranslations();
	const router = useRouter();
	const searchParams = useSearchParams();
	const [showItem, setShowItem] = useState<any>(DefaultSelect);
	const [isPending, startTransition] = useTransition();

	// Fetch ladders products
	const { products: waterfallsProducts, isLoading } = useProduct({ product_type: "waterfall" });

	// Update showItem based on URL parameters
	React.useEffect(() => {
		const pool = searchParams.get("pool");
		const tile = searchParams.get("tile");
		const ladder = searchParams.get("ladder");
		const light = searchParams.get("light");


		if (pool) {
			setShowItem((prev: typeof DefaultSelect) => ({ ...prev, pool: parseInt(pool) }));
		}

		if (tile) {
			fetchProductById(tile).then((product) => {
				setShowItem((prev: typeof DefaultSelect) => ({ ...prev, selectedTile: { id: parseInt(tile), texture: product?.data?.texture, model_3d: product?.data?.model_3d } }));
			});
		}

		if (ladder) {
			fetchProductById(ladder).then((product) => {
				setShowItem((prev: typeof DefaultSelect) => ({ ...prev, selectedLadder: { id: parseInt(ladder), texture: product?.data?.texture, model_3d: product?.data?.model_3d } }));
			});
		}

		if (light) {
			fetchProductById(light).then((product) => {
				setShowItem((prev: typeof DefaultSelect) => ({ ...prev, selectedLight: { id: parseInt(light), texture: product?.data?.texture, model_3d: product?.data?.model_3d } }));
			});
		}
	}, [searchParams]);

	React.useEffect(() => {
		if (waterfallsProducts?.data?.length > 0) {
			setShowItem((prev: typeof DefaultSelect) => ({ ...prev, selectedWaterfall: { id: waterfallsProducts?.data[0]?.id, texture: waterfallsProducts?.data[0]?.texture, model_3d: waterfallsProducts?.data[0]?.model_3d } }));
		}
	}, [waterfallsProducts]);

	const _waterfalls: any = React.useMemo(() => ({
		title: t("Type of waterfalls"),
		path: "waterfall",
		images: waterfallsProducts?.data?.map((product: any) => ({
			src: ImageBaseUrl + product?.images?.[0]?.image_path,
			alt: product?.name_en,
			data: {
				floor: product?.id,
				selectedWaterfall: {
					id: product?.id,
					texture: product?.texture,
					name: product?.name_en,
					model_3d: product?.model_3d
				}
			}
		})) || [],
		position: {
			position: { x: -0.5250531380003639, y: 0.7028408618446619, z: -0.33427545392209396 },
			target: { x: 0.7953089217506415, y: -0.2457112387437211, z: -0.26397530735397473 }
		}

	}), [t, waterfallsProducts]);

	console.log("showItem", showItem);
	const handleNextPage = async () => {
		if (showItem.selectedWaterfall?.id) {
			const response = await submitPoolRequest();
			console.log("response: ", response);
			if (response.success) {
				startTransition(() => {
					router.push("/" as any);
				});

			} else {
				toast.error(response.message);
			}
		}

	};

	return (
		<div className="h-screen w-full start-bg">
			<div className="flex h-full">
				<div className="w-full flex items-center justify-center">
					{showItem.selectedWaterfall?.id && <FormButtons
						onPrevious={() => router.back()}
						onNext={handleNextPage}
						isPending={isPending}
					/>}
					<Scene showItem={showItem} cameraSetting={_waterfalls?.position} />
					<Sidebar
						title={_waterfalls?.title}
						images={_waterfalls?.images}
						setShowItem={setShowItem}
						showItem={showItem}
						isLoading={isLoading}
					/>
				</div>
			</div>
		</div>
	);
}
